import os
from azure.storage.blob import BlobServiceClient, BlobBlock
from dotenv import load_dotenv

load_dotenv()

class UserAzureBlobStorage:
    def __init__(self, user, connection_string=None):
        self.connection_string = connection_string or os.getenv('AZURE_DEV_STORAGE_CONNECTION_STRING')
        self.user_id = user['user_id']
        self.user_email = user['email']
        container_name = f"{self.user_id.split('|')[1]}-{self.user_email.split('@')[0]}"
        self.container_name = f"{container_name}"

        self.blob_service_client = BlobServiceClient.from_connection_string(
            conn_str=self.connection_string,
        )

        self.container_client = self._get_or_create_container()

    def _get_or_create_container(self):
        try:
            container_client = self.blob_service_client.get_container_client(self.container_name)
            container_client.get_container_properties()
        except Exception:
            container_client = self.blob_service_client.create_container(self.container_name)
        return container_client

    def upload_file(self, data, blob_name):
        blob_client = self.container_client.get_blob_client(blob_name)
        blob_client.upload_blob(data)

    async def upload_chunked_blob(self, blob_name, async_chunk_generator):
        blob_client = self.container_client.get_blob_client(blob_name)
        block_list = []
        block_id = 0

        async for chunk in async_chunk_generator:
            block_id_str = str(block_id).zfill(5)
            blob_client.stage_block(block_id=block_id_str, data=chunk)
            block_list.append(BlobBlock(block_id=block_id_str))
            block_id += 1

        blob_client.commit_block_list(block_list)

    def list_blobs(self):
        return self.container_client.list_blobs()
